'use strict';

const kit = require('@nuxt/kit');
const fsExtra = require('fs-extra');
const chalk = require('chalk');
const VueLoaderPlugin = require('vue-loader/dist/pluginWebpack4');
const upath = require('upath');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

const VueLoaderPlugin__default = /*#__PURE__*/_interopDefaultLegacy(VueLoaderPlugin);

const index = kit.defineNuxtModule({
  name: "nuxt-vue3",
  configKey: "vue3",
  setup(_options, nuxt) {
    nuxt.options.alias.vue = "@vue/compat";
    if (nuxt.options.ssr) {
      nuxt.options.ssr = false;
      console.info("disabling ssr due to issues with ssr support with vue3 + nuxt2");
    }
    const version = kit.requireModulePkg("@vue/compat").version;
    nuxt.options.cli.badgeMessages.push(chalk.greenBright(chalk.bold(`[Vue v${version}]`)));
    nuxt.hook("build:templates", async (templates) => {
      var _a;
      for await (const file of templates.templatesFiles) {
        if (typeof file === "object" && ((_a = file.src) == null ? void 0 : _a.endsWith("template/client.js"))) {
          let nuxtClientSource = await fsExtra.readFile(file.src, "utf-8");
          nuxtClientSource = nuxtClientSource.replace("$parent.$children.forEach", "$parent.$children.filter(Boolean).forEach");
          await fsExtra.writeFile(upath.join(__dirname, "./templates/client.js"), nuxtClientSource);
          file.src = upath.join(__dirname, "./templates/client.js");
        }
      }
    });
    nuxt.hook("vite:extend", (ctx) => {
      ctx.config.vue.template = {
        compilerOptions: {
          compatConfig: {
            MODE: 2
          }
        }
      };
    });
    kit.extendBuild((config) => {
      const index = config.plugins.findIndex((plugin) => plugin.constructor.name === "VueLoaderPlugin");
      if (index < 0) {
        return;
      }
      config.plugins.splice(index, 1, new VueLoaderPlugin__default['default']());
    });
    const vueLoaderOptions = nuxt.options.build.loaders.vue;
    vueLoaderOptions.compilerOptions = vueLoaderOptions.compilerOptions || {};
    vueLoaderOptions.compilerOptions = {
      compatConfig: {
        MODE: 2
      }
    };
  }
});

module.exports = index;
